@@ -12,7 +12,7 @@ from .loop import loop
 from fastapi_utils.tasks import repeat_every
 import logging
 from uuid import uuid4
-from learning_loop_node.decorators.error_handler import try_except
+from .socket_response import ensure_socket_response
 from datetime import datetime
 
 
@@ -34,7 +34,7 @@ class Node(FastAPI):
             request_timeout=0.5,
             # logger=True, engineio_logger=True
         )
-        self.sio_client._trigger_event = try_except(self.sio_client._trigger_event)
+        self.sio_client._trigger_event = ensure_socket_response(self.sio_client._trigger_event)
         self.reset()
 
         @self.sio_client.on('connect')
@@ -107,16 +107,6 @@ class Node(FastAPI):
         if self.status.state != State.Offline:
             await self.send_status()
 
-    async def update_status(self, new_status: Status):
-        self.status.id = new_status.id
-        self.status.name = new_status.name
-        self.status.uptime = new_status.uptime
-        self.status.latest_error = new_status.latest_error
-
-        if self.status.state != State.Offline:
-            self.status.state = State.Idle
-        await self.send_status()
-
     async def send_status(self):
         raise Exception("Override this in subclass")
 
